@@ -12,7 +12,7 @@ use JSON;
 use Log::Any '$log';
 use Perinci::Sub::Util qw(err);
 use Scalar::Util qw(blessed);
-use SHARYANTO::Package::Util qw(package_exists);
+use Package::MoreUtil qw(package_exists);
 use Time::HiRes qw(time);
 use UUID::Random;
 
@@ -41,7 +41,7 @@ sub action_get_code_and_meta {
 
 package Perinci::Tx::Manager;
 
-our $VERSION = '0.49'; # VERSION
+our $VERSION = '0.50'; # VERSION
 
 my $proto_v = 2;
 
@@ -1393,7 +1393,7 @@ Perinci::Tx::Manager - A Rinci transaction manager
 
 =head1 VERSION
 
-This document describes version 0.49 of Perinci::Tx::Manager (from Perl distribution Perinci-Tx-Manager), released on 2014-05-02.
+This document describes version 0.50 of Perinci::Tx::Manager (from Perl distribution Perinci-Tx-Manager), released on 2014-12-05.
 
 =head1 SYNOPSIS
 
@@ -1619,7 +1619,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Tx
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Tx-Manager>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Tx-Manager>.
 
 =head1 BUGS
 
@@ -1631,11 +1631,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
